import type { ThunkAction } from 'redux-thunk';
import type { AnyAction } from 'redux';
import type { RootState } from './index';
import type { HandleErrorAction } from './error';
import type { RefreshFinishedAction } from './is-refreshing';
export declare type SortColumn = keyof typeof sortColumnToProps;
export declare type SortDirection = 'asc' | 'desc';
declare const sortColumnToProps: {
    readonly 'Name and Definition': "name";
    readonly Type: "type";
    readonly Size: "size";
    readonly Usage: "usageCount";
    readonly Properties: "properties";
};
export declare type IndexFieldsDefinition = {
    field: string;
    value: number | string;
};
export declare type IndexDefinition = {
    name: string;
    fields: {
        serialize: () => IndexFieldsDefinition[];
    };
    type: 'geo' | 'hashed' | 'text' | 'wildcard' | 'clustered' | 'columnstore';
    cardinality: 'single' | 'compound';
    properties: ('unique' | 'sparse' | 'partial' | 'ttl' | 'collation')[];
    extra: Record<string, string | number | Record<string, any>>;
    size: number;
    relativeSize: number;
    usageCount: number;
    usageSince?: Date;
};
export declare enum ActionTypes {
    LoadIndexes = "indexes/indexes/LOAD_INDEXES",
    SortIndexes = "indexes/indexes/SORT_INDEXES"
}
declare type LoadIndexesAction = {
    type: ActionTypes.LoadIndexes;
    indexes: IndexDefinition[];
};
export declare type SortIndexesAction = {
    type: ActionTypes.SortIndexes;
    indexes: IndexDefinition[];
    column: SortColumn;
    order: SortDirection;
};
declare type Actions = LoadIndexesAction | SortIndexesAction;
declare type State = IndexDefinition[];
export declare const INITIAL_STATE: State;
export default function reducer(state: State | undefined, action: Actions): State;
export declare const loadIndexes: (indexes: IndexDefinition[]) => LoadIndexesAction;
export declare const sortIndexes: (column: SortColumn, order: SortDirection) => ThunkAction<void, RootState, void, SortIndexesAction>;
export declare const fetchIndexes: () => ThunkAction<void, RootState, void, LoadIndexesAction | RefreshFinishedAction | HandleErrorAction>;
export declare const dropFailedIndex: (id: string) => ThunkAction<void, RootState, void, AnyAction>;
export {};
//# sourceMappingURL=indexes.d.ts.map